pub struct BasicAuth { /* private fields */ }Implementations
Sourceimpl BasicAuth
impl BasicAuth
Sourcepub fn single(user: impl Into<String>, pass: impl Into<String>) -> Self
pub fn single(user: impl Into<String>, pass: impl Into<String>) -> Self
Creates authentication middleware with a single static user credential.
Sourcepub fn multiple<I, T, P>(pairs: I) -> Self
pub fn multiple<I, T, P>(pairs: I) -> Self
Creates authentication middleware with multiple static user credentials.
Sourcepub fn with_verify<F>(cb: F) -> Self
pub fn with_verify<F>(cb: F) -> Self
Creates authentication middleware with a custom verification function.
Sourcepub fn users_with_verify<I, S, F>(pairs: I, cb: F) -> Self
pub fn users_with_verify<I, S, F>(pairs: I, cb: F) -> Self
Creates authentication middleware with both static credentials and custom verification.